==> freecad_0.20.2+dfsg1.orig.tar.xz: FreeCAD-0.20.2/src/Mod/Tux/Resources/translations/Tux_eu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="eu" sourcelanguage="en">
  <context>
    <name>NavigationIndicator</name>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="67"/>
      <source>Select</source>
      <translation>Hautatu</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="68"/>
      <source>Zoom</source>
      <translation>Zooma</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="69"/>
      <source>Rotate</source>
      <translation>Biratu</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="70"/>
      <source>Pan</source>
      <translation>Mugitu ezker-eskuin</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="71"/>
      <source>Tilt</source>
      <translation>Inklinatu</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="72"/>
      <source>Navigation style</source>
      <translation>Nabigazio-estiloa</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="73"/>
      <source>Page Up or Page Down key.</source>
      <translation>Page Up edo Page Down tekla.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="74"/>
      <source>Rotation focus</source>
      <translation>Biraketa-fokua</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="75"/>
      <source>Middle mouse button or H key.</source>
      <translation>Saguaren erdiko botoia edo H tekla.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="77"/>
      <source>Middle mouse button.</source>
      <translation>Saguaren erdiko botoia.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="80"/>
      <source>Navigation style not recognized.</source>
      <translation>Nabigazio-estiloa ez da onartzen.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="331"/>
      <source>Settings</source>
      <translation>Ezarpenak</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="332"/>
      <source>Orbit style</source>
      <translation>Orbita-estiloa</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="333"/>
      <source>Compact</source>
      <translation>Trinkoa</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="334"/>
      <source>Tooltip</source>
      <translation>Argibidea</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="335"/>
      <source>Turntable</source>
      <translation>Tornua</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="336"/>
      <source>Trackball</source>
      <translation>Trackball</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="337"/>
      <source>Undefined</source>
      <translation>Definitu gabea</translation>
    </message>
  </context>
</TS>

==> freecad_0.21.2+dfsg1.orig.tar.xz: FreeCAD-0.21.2/src/Mod/Tux/Resources/translations/Tux_eu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="eu" sourcelanguage="en">
  <context>
    <name>NavigationIndicator</name>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="67"/>
      <source>Select</source>
      <translation>Hautatu</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="68"/>
      <source>Zoom</source>
      <translation>Zooma</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="69"/>
      <source>Rotate</source>
      <translation>Biratu</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="70"/>
      <source>Pan</source>
      <translation>Mugitu ezker-eskuin</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="71"/>
      <source>Tilt</source>
      <translation>Inklinatu</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="72"/>
      <source>Navigation style</source>
      <translation>Nabigazio-estiloa</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="73"/>
      <source>Page Up or Page Down key.</source>
      <translation>Page Up edo Page Down tekla.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="74"/>
      <source>Rotation focus</source>
      <translation>Biraketa-fokua</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="75"/>
      <source>Middle mouse button or H key.</source>
      <translation>Saguaren erdiko botoia edo H tekla.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="77"/>
      <source>Middle mouse button.</source>
      <translation>Saguaren erdiko botoia.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="80"/>
      <source>Navigation style not recognized.</source>
      <translation>Nabigazio-estiloa ez da onartzen.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="331"/>
      <source>Settings</source>
      <translation>Ezarpenak</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="332"/>
      <source>Orbit style</source>
      <translation>Orbita-estiloa</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="333"/>
      <source>Compact</source>
      <translation>Trinkoa</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="334"/>
      <source>Tooltip</source>
      <translation>Argibidea</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="335"/>
      <source>Turntable</source>
      <translation>Tornua</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="336"/>
      <source>Free Turntable</source>
      <translation>Tornu librea</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="337"/>
      <source>Trackball</source>
      <translation>Trackball</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="338"/>
      <source>Undefined</source>
      <translation>Definitu gabea</translation>
    </message>
  </context>
</TS>
